crop_your_image library
Classes
- Crop
- Widget for the entry point of crop_your_image.
- CropController
- Controller to control crop actions.
- CropControllerDelegate
- Delegate of actions from CropController
- CropFailure
- CropResult
- CropSuccess
- DotControl
- Default dot widget placed on corners to control cropping area. This Widget automatically fits the appropriate size.
-
ImageCropper<
T> - Interface for cropping logic
-
ImageDetail<
T> - Image with detail information.
- InitialRectBuilder
- an interface for initial rect builder.
- WithAreaInitialRectBuilder
- InitialRectBuilder with ImageBasedRect named area.
- WithBuilderInitialRectBuilder
- InitialRectBuilder with builder function.
- WithSizeAndRatioInitialRectBuilder
- InitialRectBuilder with size and aspectRatio.
Enums
- CropStatus
- EdgeAlignment
- position of dot control
- ImageFormat
- Enum for the format of an image
Constants
- defaultImageCropper → const ImageImageCropper
- legacyImageCropper → const LegacyImageImageCropper
Properties
- defaultFormatDetector → FormatDetector
-
final
-
defaultImageParser
→ ImageParser<
Image> -
final
-
defaultRectValidator
→ RectValidator<
Image> -
default implementation of RectValidator
this checks if the rect is inside the image, not negative, and not negative size
final
Typedefs
-
CircleCropper<
T> = Uint8List Function(T original, {required Offset center, required ImageFormat? outputFormat, required double radius}) - CornerDotBuilder = Widget Function(double size, EdgeAlignment edgeAlignment)
- CroppingRectBuilder = ViewportBasedRect Function(ViewportBasedRect viewportRect, ImageBasedRect imageRect)
- FormatDetector = ImageFormat Function(Uint8List data)
-
Interface for detecting image format from given
data. - History = ({int redoCount, int undoCount})
- HistoryChangedCallback = void Function(History history)
- ImageBasedRect = Rect
-
ImageParser<
T> = ImageDetail< T> Function(Uint8List data, {ImageFormat? inputFormat}) -
Interface for parsing image and build ImageDetail from given
data. - OnMovedCallback = void Function(ViewportBasedRect viewportRect, ImageBasedRect imageRect)
- OverlayBuilder = Widget Function(BuildContext context, Rect rect)
-
RectCropper<
T> = Uint8List Function(T original, {required ImageFormat? outputFormat, required Size size, required Offset topLeft}) -
RectValidator<
T> = Exception? Function(T original, Offset topLeft, Offset bottomRight) - ViewportBasedRect = Rect
- WillUpdateScale = bool Function(double newScale)